@@ -16,12 +16,12 @@ from asdf._jsonschema.exceptions import RefResolutionError, ValidationError
 
 from . import constants, generic_io, reference, tagged, treeutil, util, versioning, yamlutil
 from .config import get_config
-from .exceptions import AsdfDeprecationWarning, AsdfWarning
-from .util import patched_urllib_parse
+from .exceptions import AsdfWarning
+from .util import _patched_urllib_parse
 
 YAML_SCHEMA_METASCHEMA_ID = "http://stsci.edu/schemas/yaml-schema/draft-01"
 
-__all__ = ["validate", "fill_defaults", "remove_defaults", "check_schema", "load_schema"]
+__all__ = ["check_schema", "fill_defaults", "load_schema", "remove_defaults", "validate"]
 
 PYTHON_TYPE_TO_YAML_TAG = {
     None: "null",
@@ -49,14 +49,8 @@ def _type_to_tag(type_):
     return None
 
 
-def _tag_to_uri(input_str):
-    if not input_str.startswith(constants.STSCI_SCHEMA_TAG_BASE):
-        return input_str
-    warnings.warn(
-        "Resolving by tag is deprecated. Use uris instead of tags",
-        AsdfDeprecationWarning,
-    )
-    return f"http://stsci.edu/schemas/asdf{input_str[len(constants.STSCI_SCHEMA_TAG_BASE):]}"
+def _default_resolver(uri):
+    return uri
 
 
 def validate_tag(validator, tag_pattern, instance, schema):
@@ -239,7 +233,7 @@ class _ValidationContext:
 
 @lru_cache
 def _create_validator(validators=YAML_VALIDATORS, visit_repeat_nodes=False):
-    meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, _tag_to_uri, False)
+    meta_schema = _load_schema_cached(YAML_SCHEMA_METASCHEMA_ID, None, False)
 
     type_checker = mvalidators.Draft4Validator.TYPE_CHECKER.redefine_many(
         {
@@ -339,9 +333,6 @@ def _load_schema(url):
 
 
 def _make_schema_loader(resolver):
-    if resolver is None:
-        resolver = _tag_to_uri
-
     def load_schema(url):
         # Check if this is a URI provided by the new
         # Mapping API:
@@ -381,7 +372,7 @@ def _make_jsonschema_refresolver(url_mapping):
 
     # Supplying our own implementation of urljoin_cache
     # allows asdf:// URIs to be resolved correctly.
-    urljoin_cache = lru_cache(1024)(patched_urllib_parse.urljoin)
+    urljoin_cache = lru_cache(1024)(_patched_urllib_parse.urljoin)
 
     # We set cache_remote=False here because we do the caching of
     # remote schemas here in `load_schema`, so we don't need
@@ -415,9 +406,6 @@ def load_schema(url, resolver=None, resolve_references=False):
         If ``True``, resolve all ``$ref`` references.
 
     """
-    if resolver is None:
-        resolver = _tag_to_uri
-
     # We want to cache the work that went into constructing the schema, but returning
     # the same object is treacherous, because users who mutate the result will not
     # expect that they're changing the schema everywhere.
@@ -465,7 +453,7 @@ def _safe_resolve(resolver, json_id, uri):
 @lru_cache
 def _load_schema_cached(url, resolver, resolve_references):
     if resolver is None:
-        resolver = _tag_to_uri
+        resolver = _default_resolver
     loader = _make_schema_loader(resolver)
     schema, url = loader(url)
 
@@ -538,7 +526,7 @@ def get_validator(
     validator : jsonschema.Validator
     """
     if ctx is None:
-        from .asdf import AsdfFile
+        from ._asdf import AsdfFile
 
         ctx = AsdfFile()
 
@@ -641,7 +629,7 @@ def validate(instance, ctx=None, schema=None, validators=None, reading=False, *a
         reading vs writing files.
     """
     if ctx is None:
-        from .asdf import AsdfFile
+        from ._asdf import AsdfFile
 
         ctx = AsdfFile()
 
@@ -735,9 +723,9 @@ def check_schema(schema, validate_default=True):
         applicable_validators = methodcaller("items")
 
     meta_schema_id = schema.get("$schema", YAML_SCHEMA_METASCHEMA_ID)
-    meta_schema = _load_schema_cached(meta_schema_id, _tag_to_uri, False)
+    meta_schema = _load_schema_cached(meta_schema_id, None, False)
 
-    resolver = _make_jsonschema_refresolver(_tag_to_uri)
+    resolver = _make_jsonschema_refresolver(_default_resolver)
 
     cls = mvalidators.create(
         meta_schema=meta_schema,
